/**************************************************************************
 * This is a test program and example that uses libidmef to
 * construct an IDMEF XML message and print it to a file.
 *
 * The program was tested, and successfully ran with the following
 * commands in the directory that libidmef was built in:
 *
 * NOTE: Now you can indent your tree with the -t option.
 *
 * Linux - Redhat 6.1
 * ------------------
 * # gcc -L. -o example1 example1.c -lidmef -lm -lxml
 * # ./example1 [-i]
 *
 * OpenBSD 2.6
 * -----------
 * # gcc -L. -L/usr/local/lib -o example1 example1.c -lidmef -lm -lxml -lz
 * # ./example1 [-i]
 *
 * E-mail me if problems occur (joey@silicondefense.com)
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "idmefxml.h"

#define IDMEF_MESSAGE_DTD       "idmef-message.dtd"
#define XML_VERSION             "1.0"
#define ALERT_VERSION           "1"
#define ANALYZER_ID             "0000000000001"
#define ANALYZER_LOCATION       "Client 1 network"
#define IDMEF_LOG_FILE_NAME     "idmef_alerts.log"

int main(int argc, char **argv) {

  int i= 0;
  FILE *idmef_log_file;

  /* Are we indenting our XML tree?
     This is overkill, but it's easier to add more options later */

  if(argc > 1)
    if((*++argv)[0] == '-')
      if(*++argv[0] == 'i')
	xmlKeepBlanksDefault(0);

  idmef_log_file = fopen( IDMEF_LOG_FILE_NAME,"a");
  if (!idmef_log_file)
  {
    fprintf(stderr, "Error opening %s\n", IDMEF_LOG_FILE_NAME);
    return 0;
  }

  /* Initialize the global variables */

  globalsInit( IDMEF_MESSAGE_DTD );

  /* Create the current document structure, passing in the current version
     of XML (1.0)  */

  createCurrentDoc( XML_VERSION );

  /* Construct the IDMEF Message, building off of the root node of the
     current document */

  newIDMEF_Message(
    newAlert(
        newSimpleElement("alertid","999"),
	newSimpleElement("impact","unknown"),
	newSimpleElement("version",ALERT_VERSION),
	newTime(
	   newSimpleElement("ntpstamp","0x39b03726.0x0"),
	   newSimpleElement("date","2000-09-01"),
	   newSimpleElement("time","16:09:26"),
           NULL
        ),
        newAnalyzer(
           newSimpleElement("ident",ANALYZER_ID),
           newNode(
              newSimpleElement("category","dns"),
              newSimpleElement("location",ANALYZER_LOCATION),
              newSimpleElement("name",getenv("HOSTNAME")),
              NULL
           ),
           NULL
        ),
        newClassification(
           newSimpleElement("name","IDS305 - WEB IIS - View Source via Translate Header"),
	   newSimpleElement("url","http://www.whitehats.com/IDS/305"),
           NULL
        ),
        newSource(
           newSimpleElement("spoofed","unknown"),
           newNode(
              newAddress(
                newSimpleElement("category","ipv4-addr"),
                newSimpleElement("address","222.222.222.222"),
                NULL
              ),
              NULL
           ),
           NULL
        ),
        newTarget(
           newSimpleElement("decoy","unknown"),
           newNode(
              newSimpleElement("category","dns"),
              newSimpleElement("location","Client 1 network"),
              newAddress(
                 newSimpleElement("category","ipv4-addr"),
                 newSimpleElement("address","111.111.111.111"),
                 NULL
              ),
              NULL
           ),
           newService(
              newSimpleElement("ident","0"),
              newSimpleElement("dport","80"),
              newSimpleElement("sport","2561"),
              NULL
           ),
           NULL
        ),
        NULL
     ),
     NULL
  );

  /* Print the current message to the log file */

  printCurrentMessage(idmef_log_file);
  fflush(idmef_log_file);
  fclose(idmef_log_file);

  /* Cleanup */

  clearCurrentDoc();

}
